==> cotrix-web-common-0.1.0-20140410.014236-30.jar: org/cotrix/web/common/client/widgets/ItemToolbar.java <==
/**
 * 
 */
package org.cotrix.web.common.client.widgets;

import org.cotrix.web.common.client.util.FadeAnimation;
import org.cotrix.web.common.client.util.FadeAnimation.Speed;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.shared.EventHandler;
import com.google.gwt.event.shared.GwtEvent;
import com.google.gwt.event.shared.HandlerRegistration;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiHandler;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.PushButton;
import com.google.gwt.user.client.ui.Widget;

/**
 * @author "Federico De Faveri federico.defaveri@fao.org"
 *
 */
public class ItemToolbar extends Composite {

	public enum ItemButton {MINUS, PLUS};

	@UiTemplate("ItemToolbar.ui.xml")
	interface ItemToolbarUiBinder extends UiBinder<Widget, ItemToolbar> {}
	private static ItemToolbarUiBinder uiBinder = GWT.create(ItemToolbarUiBinder.class);
	
	@UiField PushButton plus;
	@UiField PushButton minus;
	
	protected FadeAnimation plusAnimation;
	protected FadeAnimation minusAnimation;

	public ItemToolbar() {
		initWidget(uiBinder.createAndBindUi(this));
		plusAnimation = new FadeAnimation(plus.getElement());
		minusAnimation = new FadeAnimation(minus.getElement());
	}

	@UiHandler("plus")
	protected void onPlusClick(ClickEvent event)
	{
		fireEvent(new ButtonClickedEvent(ItemButton.PLUS));
	}

	@UiHandler("minus")
	protected void onMinusClick(ClickEvent event)
	{
		fireEvent(new ButtonClickedEvent(ItemButton.MINUS));
	}
	
	public HandlerRegistration addButtonClickedHandler(ButtonClickedHandler handler)
	{
		return addHandler(handler, ButtonClickedEvent.getType());
	}
	
	public void setVisible(ItemButton button, boolean visible, boolean animation)
	{
		if (animation) setVisible(button, visible);
		else setVisible(button, visible, Speed.IMMEDIATE);
	}

	public void setVisible(ItemButton button, boolean visible)
	{
		setVisible(button, visible, Speed.FAST);
	}
	
	public void setVisible(ItemButton button, boolean visible, Speed speed)
	{
		switch (button) {
			case MINUS: minusAnimation.setVisibility(visible, speed); break;
			case PLUS: plusAnimation.setVisibility(visible, speed); break;
		}
	}
	

	public interface ButtonClickedHandler extends EventHandler {
		void onButtonClicked(ButtonClickedEvent event);
	}

	public static class ButtonClickedEvent extends GwtEvent<ButtonClickedHandler> {

		public static Type<ButtonClickedHandler> TYPE = new Type<ButtonClickedHandler>();
		
		protected ItemButton button;

		public ButtonClickedEvent(ItemButton button) {
			this.button = button;
		}

		/**
		 * @return the button
		 */
		public ItemButton getButton() {
			return button;
		}

		@Override
		protected void dispatch(ButtonClickedHandler handler) {
			handler.onButtonClicked(this);
		}

		@Override
		public Type<ButtonClickedHandler> getAssociatedType() {
			return TYPE;
		}

		public static Type<ButtonClickedHandler> getType() {
			return TYPE;
		}
	}

}

==> cotrix-web-common-0.2.0-20140629.003527-5.jar: org/cotrix/web/common/client/widgets/ItemToolbar.java <==
/**
 * 
 */
package org.cotrix.web.common.client.widgets;

import org.cotrix.web.common.client.util.FadeAnimation.Speed;

import com.google.gwt.core.client.GWT;
import com.google.gwt.event.dom.client.ClickEvent;
import com.google.gwt.event.shared.EventHandler;
import com.google.gwt.event.shared.GwtEvent;
import com.google.gwt.event.shared.HandlerRegistration;
import com.google.gwt.uibinder.client.UiBinder;
import com.google.gwt.uibinder.client.UiField;
import com.google.gwt.uibinder.client.UiHandler;
import com.google.gwt.uibinder.client.UiTemplate;
import com.google.gwt.user.client.ui.Composite;
import com.google.gwt.user.client.ui.PushButton;
import com.google.gwt.user.client.ui.Widget;

/**
 * @author "Federico De Faveri federico.defaveri@fao.org"
 *
 */
public class ItemToolbar extends Composite {

	public enum ItemButton {MINUS, PLUS};

	@UiTemplate("ItemToolbar.ui.xml")
	interface ItemToolbarUiBinder extends UiBinder<Widget, ItemToolbar> {}
	private static ItemToolbarUiBinder uiBinder = GWT.create(ItemToolbarUiBinder.class);
	
	@UiField PushButton plus;
	@UiField PushButton minus;

	public ItemToolbar() {
		initWidget(uiBinder.createAndBindUi(this));
	}

	@UiHandler("plus")
	protected void onPlusClick(ClickEvent event)
	{
		fireEvent(new ButtonClickedEvent(ItemButton.PLUS));
	}

	@UiHandler("minus")
	protected void onMinusClick(ClickEvent event)
	{
		fireEvent(new ButtonClickedEvent(ItemButton.MINUS));
	}
	
	public HandlerRegistration addButtonClickedHandler(ButtonClickedHandler handler)
	{
		return addHandler(handler, ButtonClickedEvent.getType());
	}
	
	public void setVisible(ItemButton button, boolean visible, boolean animation)
	{
		setVisible(button, visible);
		/*if (animation) setVisible(button, visible);
		else setVisible(button, visible, Speed.IMMEDIATE);*/
	}

	public void setVisible(ItemButton button, boolean visible)
	{
		switch (button) {
			case MINUS: minus.setEnabled(visible); break;
			case PLUS: plus.setEnabled(visible); break;
		}
		/*setVisible(button, visible, Speed.FAST);*/
	}
	
	public void setVisible(ItemButton button, boolean visible, Speed speed)
	{
		setVisible(button, visible);
		/*switch (button) {
			case MINUS: minusAnimation.setVisibility(visible, speed); break;
			case PLUS: plusAnimation.setVisibility(visible, speed); break;
		}*/
	}
	

	public interface ButtonClickedHandler extends EventHandler {
		void onButtonClicked(ButtonClickedEvent event);
	}

	public static class ButtonClickedEvent extends GwtEvent<ButtonClickedHandler> {

		public static Type<ButtonClickedHandler> TYPE = new Type<ButtonClickedHandler>();
		
		protected ItemButton button;

		public ButtonClickedEvent(ItemButton button) {
			this.button = button;
		}

		/**
		 * @return the button
		 */
		public ItemButton getButton() {
			return button;
		}

		@Override
		protected void dispatch(ButtonClickedHandler handler) {
			handler.onButtonClicked(this);
		}

		@Override
		public Type<ButtonClickedHandler> getAssociatedType() {
			return TYPE;
		}

		public static Type<ButtonClickedHandler> getType() {
			return TYPE;
		}
	}

}
